<?php

/**
 * Fired during plugin activation.
 *
 * @link          https://plugins360.com
 * @since         1.0.0
 *
 * @package       AIOVG
 * @subpackage    AIOVG/includes
 */

// Exit if accessed directly
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * AIOVG_Activator class.
 *
 * @since    1.0.0
 */
class AIOVG_Activator {

	/**
	 * Called when the plugin is activated.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {
	
		// Insert plugin settings and default values for the first time
		$options = array(
			'aiovg_general_settings' => array(
				'bootstrap'          => array( 
					'css' => 'css'
				),
				'fontawesome'        => 1,
				'delete_plugin_data' => 1
			),
			'aiovg_player_settings' => array(
				'width'    => '',
				'ratio'    => 56.25,
				'autoplay' => 1,
				'loop'     => 0,
				'preload'  => 'metadata',
				'controls' => array(
					'playpause'  => 'playpause',
					'current'    => 'current',
					'progress'   => 'progress', 
					'duration'   => 'duration',
					'tracks'     => 'tracks',
					'volume'     => 'volume', 
					'fullscreen' => 'fullscreen'					
				)
			),
			'aiovg_image_settings' => array(
				'ratio' => 75
			),
			'aiovg_categories_settings' => array(
				'columns'          => 3,
				'orderby'          => 'name',
				'order'            => 'asc',
				'show_description' => 1,
				'show_count'       => 1,				
				'hide_empty'       => 0
			),
			'aiovg_videos_settings' => array(
				'columns'        => 3,
				'limit'          => 10,
				'orderby'        => 'date',
				'order'          => 'desc',
				'display'        => array(
					'count'    => 'count',
					'category' => 'category',
					'date'     => 'date',
					'user'     => 'user',
					'views'    => 'views',
					'duration' => 'duration',
					'excerpt'  => 'excerpt'
				),
				'excerpt_length' => 75
			),
			'aiovg_video_settings' => array(
				'display'      => array( 
					'category' => 'category', 
					'date'     => 'date', 
					'user'     => 'user', 
					'views'    => 'views', 
					'related'  => 'related'
				),
				'has_comments' => 1
			),
			'aiovg_permalink_settings' => array(
				'video' => 'aiovg_videos'
			),
			'aiovg_socialshare_settings' => array(				
				'services' => array( 
					'facebook'  => 'facebook',
					'twitter'   => 'twitter',
					'gplus'     => 'gplus',
					'linkedin'  => 'linkedin',
					'pinterest' => 'pinterest'
				)
			),
			'aiovg_page_settings' => array(
			)
		);
		
		foreach ( $options as $option_name => $defaults ) {
			if ( false == get_option( $option_name ) ) {	
				if ( 'aiovg_page_settings' == $option_name ) $defaults = aiovg_insert_custom_pages();		
        		add_option( $option_name, $defaults );						
    		}
		}
		
		// Add custom AIOVG capabilities
		if ( ! get_option( 'aiovg_version' ) ) {
			$roles = new AIOVG_Roles;
			$roles->add_caps();
		}
		
		// Insert plugin version
		add_option( 'aiovg_version', AIOVG_PLUGIN_VERSION );
		
		// Add transient to manage the welcome page
		set_transient( 'aiovg_welcome_redirect', true, 60 );

	}

}
