<?php

/**
 * Video Player.
 *
 * @link          https://plugins360.com
 * @since         1.0.0
 *
 * @package       AIOVG
 * @subpackage    AIOVG/public/templates
 */
 
$player_settings = get_option( 'aiovg_player_settings' );

$post_id = (int) get_query_var( 'aiovg_video', 0 );

$post_meta = array();
if( $post_id > 0 ) {
	$post_meta = get_post_meta( $post_id );
}

// Controls
$controls = array();
$features = array( 'playpause', 'current', 'progress', 'duration', 'tracks', 'volume', 'fullscreen' );

foreach ( $features as $feature ) {

	if ( isset( $_GET[ $feature ] ) ) {
	
		if ( 1 == (int) $_GET[ $feature ] ) {
			$controls[] = $feature;
		}
		
	} else {
	
		if ( isset( $player_settings['controls'][ $feature ] ) ) {
			$controls[] = $feature;
		}
		
	}
	
}

$controls = apply_filters( 'aiovg_video_controls', $controls );

// Attributes
$attributes = array();

if ( isset( $_GET['poster'] ) ) {
	$attributes['poster'] = $_GET['poster'];
} elseif ( ! empty( $post_meta ) ) {
	$attributes['poster'] = aiovg_get_image_url( $post_meta['image_id'][0], 'large', $post_meta['image'][0], 'player' );
}

if( ! empty( $attributes['poster'] ) ) {
	$attributes['poster'] = esc_url( $attributes['poster'] );
	
	if ( false !== strpos( $attributes['poster'], 'youtube' ) ) {
		$attributes['poster'] = str_replace( array( 'https:', 'http:' ), '', $attributes['poster'] );
	}
}

$autoplay = isset( $_GET['autoplay'] ) ? (int) $_GET['autoplay'] : $player_settings['autoplay'];
if ( ! empty( $autoplay ) ) {
	$attributes['autoplay'] = true;
}

$loop = isset( $_GET['loop'] ) ? (int) $_GET['loop'] : $player_settings['loop'];
if ( ! empty( $loop ) ) {
	$attributes['loop'] = true;
}

$attributes['preload'] = esc_attr( $player_settings['preload'] );

$attributes = apply_filters( 'aiovg_video_attributes', $attributes );

// Sources
$types = array(
	'all'         => array( 'mp4', 'webm', 'ogv', 'youtube', 'vimeo', 'dailymotion', 'facebook' ),
	'default'     => array( 'mp4', 'webm', 'ogv' ),
	'youtube'     => array( 'youtube' ),
	'vimeo'       => array( 'vimeo' ),
	'dailymotion' => array( 'dailymotion' ),
	'facebook'    => array( 'facebook' )
);

if ( ! empty( $post_meta ) ) {
	$types = array_key_exists( $post_meta['type'][0], $types ) ? $types[ $post_meta['type'][0] ] : array();	
} else {
	$types = $types['all'];
}

$sources = array();
$formats = array();

foreach ( $types as $type ) {

	if ( ! empty( $post_meta ) ) {
		$src = ! empty( $post_meta[ $type ][0] ) ? $post_meta[ $type ][0] : '';
	} else {
		$src = isset( $_GET[ $type ] ) ? sanitize_text_field( $_GET[ $type ] ) : '';
	}
	
	if ( ! empty( $src ) ) {		
		$mime = "video/{$type}";

		$sources[] = array(
			'type' => $mime,
			'src'  => $src
		);
		
		$formats[] = $type;
	}
	
}

$sources = apply_filters( 'aiovg_video_sources', $sources );

// Tracks
$tracks = array();

if ( in_array( 'tracks', $controls ) && ! empty( $post_meta['track'] ) ) {

	foreach ( $post_meta['track'] as $track ) {
		$tracks[] = unserialize( $track );
	}
	
}

$tracks = apply_filters( 'aiovg_video_tracks', $tracks );

// Mobile
$is_mobile = false;
$use_native_controls = 0;

if ( isset( $_SERVER['HTTP_USER_AGENT'] ) && preg_match( '/iPhone|iPod|iPad|BlackBerry|Android/', $_SERVER['HTTP_USER_AGENT'] ) ) {
	$is_mobile = true;
}

if ( $is_mobile ) {
	$attributes['autoplay'] = false;
	
	if ( in_array( 'youtube', $formats ) || in_array( 'vimeo', $formats ) || in_array( 'dailymotion', $formats ) || in_array( 'facebook', $formats ) ) {
		$attributes['poster'] = '';
		$use_native_controls  = 1;
	}
}
?>
<!DOCTYPE html>
<html>
<head>
<link rel="stylesheet" href="<?php echo AIOVG_PLUGIN_URL; ?>public/assets/mediaelement/mediaelementplayer.css?v=4.2.8" />
<style type="text/css">
	html, 
	body, 
	video, 
	iframe {
		width: 100% !important;
		height: 100% !important;
		margin:0 !important; 
		padding:0 !important; 
		overflow: hidden;
	}
		
	video, 
	iframe {
		display: block;
	}
		
	.mejs__container, 
	.mejs__layer {
		width: 100% !important;
		height: 100% !important;
	}
	
	.mejs__captions-layer {
		pointer-events: none;
	}
</style>
<script src="<?php echo includes_url(); ?>js/jquery/jquery.js?v=<?php echo AIOVG_PLUGIN_VERSION; ?>" type="text/javascript"></script>
<script src="<?php echo AIOVG_PLUGIN_URL; ?>public/assets/mediaelement/mediaelement-and-player.min.js?v=4.2.8" type="text/javascript"></script>
<?php if ( in_array( 'vimeo', $formats ) ) : ?>
	<script src="<?php echo AIOVG_PLUGIN_URL; ?>public/assets/mediaelement/renderers/vimeo.min.js?v=4.2.8" type="text/javascript"></script>
<?php endif; ?>
<?php if ( in_array( 'dailymotion', $formats ) ) : ?>
	<script src="<?php echo AIOVG_PLUGIN_URL; ?>public/assets/mediaelement/renderers/dailymotion.min.js?v=4.2.8" type="text/javascript"></script>
<?php endif; ?>
<?php if ( in_array( 'facebook', $formats ) ) : ?>
	<script src="<?php echo AIOVG_PLUGIN_URL; ?>public/assets/mediaelement/renderers/facebook.min.js?v=4.2.8" type="text/javascript"></script>
<?php endif; ?>
<script type="text/javascript">
(function( $ ) {
	'use strict';
	
	$(function() {
		var views_count_updated = 0;
		
		$( 'video' ).mediaelementplayer({
			pluginPath: '<?php echo AIOVG_PLUGIN_URL; ?>public/assets/mediaelement/',
			features: <?php echo json_encode( $controls ); ?>,
			AndroidUseNativeControls: <?php echo $use_native_controls; ?>,
			iPadUseNativeControls: <?php echo $use_native_controls; ?>,
			iPhoneUseNativeControls: <?php echo $use_native_controls; ?>,
			youtube: { showinfo: 0, rel: 0, iv_load_policy: 3 },
			success: function( media ) {
						
				<?php if ( count( $sources ) && ! empty( $attributes['autoplay'] ) ) : ?>
					// An ugly hack to autoplay Vimeo videos
					if ( ~media.rendererName.indexOf( 'vimeo' ) || ~media.rendererName.indexOf( 'dash' ) ) {
						media.play();
					}
				<?php endif; ?>
				
				// Fired when the media is ready to start playing
				media.addEventListener( 'play', function( e ) {
				
					if ( ! views_count_updated ) {
						var data = {
							'action': 'aiovg_update_views_count',
							'post_id': <?php echo $post_id; ?>,
							'security': '<?php echo wp_create_nonce( 'aiovg_video_{$post_id}_views_nonce' ); ?>'
						};
						
						$.post( '<?php echo admin_url( 'admin-ajax.php' ); ?>', data, function( response ) {
							// console.log( 'Views count updated' );
						});
						
						views_count_updated = 1;
					};
				
				});
				
			}
		});
	});

})( jQuery );
</script>
<?php do_action( 'aiovg_player_head' ); ?>
</head>
<body>
    <video <?php the_aiovg_video_attributes( $attributes ); ?>>
        <?php 
		// Sources
		foreach ( $sources as $source ){
			printf( '<source type="%s" src="%s" />', esc_attr( $source['type'] ), esc_url_raw( $source['src'] ) );
		}
		
		// Tracks
		foreach ( $tracks as $track ) {
        	printf( '<track src="%s" kind="subtitles" srclang="%s" label="%s">', esc_url_raw( $track['src'] ), esc_attr( $track['srclang'] ), esc_attr( $track['label'] ) );
		}
       ?>       
	</video>
    
    <?php do_action( 'aiovg_player_footer' ); ?>
</body>
</html>
